@@ -25,40 +25,36 @@ pigs1_exp <- tibble::tibble(
     "0.24", "0.24", "0.24", "0.24", "0.24", "0.24", "0.24"
   ),
   n = c(
-    25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 29L, 29L,
-    29L, 29L, 29L, 29L, 29L, 29L, 29L, 29L, 24L, 24L, 24L, 24L, 24L,
-    24L, 24L, 24L, 24L, 24L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L,
-    27L, 27L, 29L, 29L, 29L, 29L, 29L, 29L, 29L, 29L, 29L, 29L, 27L,
-    27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 31L, 31L, 31L, 31L,
-    31L, 31L, 31L, 31L, 31L, 31L, 28L, 28L, 28L, 28L, 28L, 28L, 28L,
-    28L, 28L, 28L, 20L, 21L, 22L, 23L, 24L, 26L, 27L, 28L, 29L, 30L,
-    24L, 25L, 26L, 27L, 28L, 30L, 31L, 32L, 33L, 34L, 19L, 20L, 21L,
-    22L, 23L, 25L, 26L, 27L, 28L, 29L, 22L, 23L, 24L, 25L, 26L, 28L,
-    29L, 30L, 31L, 32L, 24L, 25L, 26L, 27L, 28L, 30L, 31L, 32L, 33L,
-    34L, 22L, 23L, 24L, 25L, 26L, 28L, 29L, 30L, 31L, 32L, 26L, 27L,
-    28L, 29L, 30L, 32L, 33L, 34L, 35L, 36L, 23L, 24L, 25L, 26L, 27L,
-    29L, 30L, 31L, 32L, 33L
+    25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 29L, 29L, 29L, 29L, 29L,
+    29L, 29L, 29L, 29L, 29L, 24L, 24L, 24L, 24L, 24L, 24L, 24L, 24L, 24L, 24L,
+    27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 29L, 29L, 29L, 29L, 29L,
+    29L, 29L, 29L, 29L, 29L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L,
+    31L, 31L, 31L, 31L, 31L, 31L, 31L, 31L, 31L, 31L, 28L, 28L, 28L, 28L, 28L,
+    28L, 28L, 28L, 28L, 28L, 20L, 21L, 22L, 23L, 24L, 26L, 27L, 28L, 29L, 30L,
+    24L, 25L, 26L, 27L, 28L, 30L, 31L, 32L, 33L, 34L, 19L, 20L, 21L, 22L, 23L,
+    25L, 26L, 27L, 28L, 29L, 22L, 23L, 24L, 25L, 26L, 28L, 29L, 30L, 31L, 32L,
+    24L, 25L, 26L, 27L, 28L, 30L, 31L, 32L, 33L, 34L, 22L, 23L, 24L, 25L, 26L,
+    28L, 29L, 30L, 31L, 32L, 26L, 27L, 28L, 29L, 30L, 32L, 33L, 34L, 35L, 36L,
+    23L, 24L, 25L, 26L, 27L, 29L, 30L, 31L, 32L, 33L
   ),
   consistency = c(
-    FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE,
-    FALSE, FALSE, FALSE, FALSE, TRUE, FALSE, TRUE, FALSE, FALSE,
-    FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE,
-    FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE,
-    TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, TRUE, FALSE,
-    FALSE, FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE,
-    FALSE, FALSE, TRUE, TRUE, FALSE, FALSE, TRUE, FALSE, TRUE, FALSE,
-    FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE,
-    FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, TRUE, FALSE, FALSE,
-    TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, FALSE, FALSE,
-    TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, FALSE, TRUE,
-    FALSE, FALSE, FALSE, TRUE, FALSE, TRUE, FALSE, FALSE, FALSE,
-    TRUE, FALSE, FALSE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE,
-    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, FALSE, FALSE,
-    FALSE, FALSE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, TRUE, TRUE,
-    FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, TRUE, FALSE, FALSE,
-    TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, TRUE
+    FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE,
+    FALSE, FALSE, TRUE, FALSE, TRUE, FALSE, FALSE, FALSE, TRUE, FALSE, FALSE,
+    TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, TRUE,
+    FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE,
+    TRUE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, FALSE, FALSE,
+    TRUE, FALSE, FALSE, FALSE, TRUE, TRUE, FALSE, FALSE, TRUE, FALSE, TRUE, FALSE,
+    FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE,
+    FALSE, TRUE, FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE,
+    FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, TRUE, FALSE, FALSE, FALSE,
+    FALSE, FALSE, TRUE, FALSE, TRUE, FALSE, FALSE, FALSE, TRUE, FALSE, TRUE,
+    FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, TRUE, TRUE, FALSE, FALSE, FALSE,
+    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, FALSE, FALSE,
+    FALSE, FALSE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, TRUE, TRUE, FALSE,
+    FALSE, FALSE, FALSE, FALSE, TRUE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE,
+    TRUE, FALSE, FALSE, FALSE, TRUE
   ),
-  ratio = c(
+  probability = c(
     0.75, 0.75, 0.75, 0.75, 0.75, 0.75, 0.75, 0.75, 0.75, 0.75, 0.71, 0.71, 0.71,
     0.71, 0.71, 0.71, 0.71, 0.71, 0.71, 0.71, 0.76, 0.76, 0.76, 0.76, 0.76, 0.76,
     0.76, 0.76, 0.76, 0.76, 0.73, 0.73, 0.73, 0.73, 0.73, 0.73, 0.73, 0.73, 0.73,
@@ -102,29 +98,23 @@ pigs2_exp <- tibble::tibble(
     "0.554", "0.554", "0.554", "0.554"
   ),
   n = c(
-    150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L,
-    150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L,
-    150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L,
-    150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L,
-    150L, 150L, 150L, 150L, 150L, 150L, 150L, 145L, 146L, 147L, 148L,
-    149L, 151L, 152L, 153L, 154L, 155L, 145L, 146L, 147L, 148L, 149L,
-    151L, 152L, 153L, 154L, 155L, 145L, 146L, 147L, 148L, 149L, 151L,
-    152L, 153L, 154L, 155L, 145L, 146L, 147L, 148L, 149L, 151L, 152L,
-    153L, 154L, 155L, 145L, 146L, 147L, 148L, 149L, 151L, 152L, 153L,
-    154L, 155L
+    150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L,
+    150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L,
+    150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L,
+    150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 150L, 145L, 146L,
+    147L, 148L, 149L, 151L, 152L, 153L, 154L, 155L, 145L, 146L, 147L, 148L, 149L,
+    151L, 152L, 153L, 154L, 155L, 145L, 146L, 147L, 148L, 149L, 151L, 152L, 153L,
+    154L, 155L, 145L, 146L, 147L, 148L, 149L, 151L, 152L, 153L, 154L, 155L, 145L,
+    146L, 147L, 148L, 149L, 151L, 152L, 153L, 154L, 155L
   ),
   consistency = rep(
     c(
-      FALSE, TRUE, FALSE, TRUE, FALSE, TRUE, FALSE, TRUE, FALSE,
-      TRUE, FALSE, TRUE, FALSE, TRUE, FALSE, TRUE, FALSE, TRUE, FALSE,
-      TRUE, FALSE
+      FALSE, TRUE, FALSE, TRUE, FALSE, TRUE, FALSE, TRUE, FALSE, TRUE, FALSE, TRUE,
+      FALSE, TRUE, FALSE, TRUE, FALSE, TRUE, FALSE, TRUE, FALSE
     ),
-    c(
-      4L, 1L, 8L, 1L, 5L, 2L, 5L, 1L, 7L, 1L, 9L, 1L, 22L, 1L, 1L,
-      1L, 4L, 1L, 18L, 1L, 6L
-    )
+    c(4L, 1L, 8L, 1L, 5L, 2L, 5L, 1L, 7L, 1L, 9L, 1L, 22L, 1L, 1L, 1L, 4L, 1L, 18L, 1L, 6L)
   ),
-  ratio = c(
+  probability = c(
     0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85,
     0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85,
     0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85, 0.85,
@@ -171,33 +161,30 @@ pigs1_include_reported_exp <- tibble::tibble(
     "0.24", "0.24", "0.24", "0.24", "0.24"
   ),
   n = c(
-    25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 29L,
-    29L, 29L, 29L, 29L, 29L, 29L, 29L, 29L, 29L, 29L, 24L, 24L, 24L,
-    24L, 24L, 24L, 24L, 24L, 24L, 24L, 24L, 27L, 27L, 27L, 27L, 27L,
-    27L, 27L, 27L, 27L, 27L, 27L, 29L, 29L, 29L, 29L, 29L, 29L, 29L,
-    29L, 29L, 29L, 29L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L,
-    27L, 27L, 31L, 31L, 31L, 31L, 31L, 31L, 31L, 31L, 31L, 31L, 31L,
-    28L, 28L, 28L, 28L, 28L, 28L, 28L, 28L, 28L, 28L, 28L, 20L, 21L,
-    22L, 23L, 24L, 25L, 26L, 27L, 28L, 29L, 30L, 24L, 25L, 26L, 27L,
-    28L, 29L, 30L, 31L, 32L, 33L, 34L, 19L, 20L, 21L, 22L, 23L, 24L,
-    25L, 26L, 27L, 28L, 29L, 22L, 23L, 24L, 25L, 26L, 27L, 28L, 29L,
-    30L, 31L, 32L, 24L, 25L, 26L, 27L, 28L, 29L, 30L, 31L, 32L, 33L,
-    34L, 22L, 23L, 24L, 25L, 26L, 27L, 28L, 29L, 30L, 31L, 32L, 26L,
-    27L, 28L, 29L, 30L, 31L, 32L, 33L, 34L, 35L, 36L, 23L, 24L, 25L,
-    26L, 27L, 28L, 29L, 30L, 31L, 32L, 33L
+    25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 25L, 29L, 29L, 29L, 29L,
+    29L, 29L, 29L, 29L, 29L, 29L, 29L, 24L, 24L, 24L, 24L, 24L, 24L, 24L, 24L,
+    24L, 24L, 24L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 27L, 29L,
+    29L, 29L, 29L, 29L, 29L, 29L, 29L, 29L, 29L, 29L, 27L, 27L, 27L, 27L, 27L,
+    27L, 27L, 27L, 27L, 27L, 27L, 31L, 31L, 31L, 31L, 31L, 31L, 31L, 31L, 31L,
+    31L, 31L, 28L, 28L, 28L, 28L, 28L, 28L, 28L, 28L, 28L, 28L, 28L, 20L, 21L,
+    22L, 23L, 24L, 25L, 26L, 27L, 28L, 29L, 30L, 24L, 25L, 26L, 27L, 28L, 29L,
+    30L, 31L, 32L, 33L, 34L, 19L, 20L, 21L, 22L, 23L, 24L, 25L, 26L, 27L, 28L,
+    29L, 22L, 23L, 24L, 25L, 26L, 27L, 28L, 29L, 30L, 31L, 32L, 24L, 25L, 26L,
+    27L, 28L, 29L, 30L, 31L, 32L, 33L, 34L, 22L, 23L, 24L, 25L, 26L, 27L, 28L,
+    29L, 30L, 31L, 32L, 26L, 27L, 28L, 29L, 30L, 31L, 32L, 33L, 34L, 35L, 36L,
+    23L, 24L, 25L, 26L, 27L, 28L, 29L, 30L, 31L, 32L, 33L
   ),
   consistency = rep(
     rep(c(FALSE, TRUE), 40),
     c(
-      3L, 1L, 3L, 1L, 6L, 1L, 2L, 1L, 3L, 1L, 2L, 1L, 3L, 1L, 3L,
-      1L, 2L, 1L, 3L, 1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L, 1L, 5L, 1L, 3L,
-      1L, 3L, 2L, 2L, 1L, 2L, 1L, 3L, 1L, 2L, 1L, 3L, 1L, 3L, 1L, 3L,
-      1L, 3L, 1L, 5L, 1L, 3L, 2L, 5L, 1L, 1L, 1L, 4L, 1L, 1L, 1L, 3L,
-      1L, 3L, 2L, 12L, 1L, 5L, 2L, 4L, 2L, 6L, 2L, 2L, 1L, 3L, 1L,
-      3L, 1L
+      3L, 1L, 3L, 1L, 6L, 1L, 2L, 1L, 3L, 1L, 2L, 1L, 3L, 1L, 3L, 1L, 2L, 1L, 3L,
+      1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L, 1L, 5L, 1L, 3L, 1L, 3L, 2L, 2L, 1L, 2L, 1L,
+      3L, 1L, 2L, 1L, 3L, 1L, 3L, 1L, 3L, 1L, 3L, 1L, 5L, 1L, 3L, 2L, 5L, 1L, 1L,
+      1L, 4L, 1L, 1L, 1L, 3L, 1L, 3L, 2L, 12L, 1L, 5L, 2L, 4L, 2L, 6L, 2L, 2L, 1L,
+      3L, 1L, 3L, 1L
     )
   ),
-  ratio = c(
+  probability = c(
     0.75, 0.75, 0.75, 0.75, 0.75, 0.75, 0.75, 0.75, 0.75, 0.75, 0.75, 0.71, 0.71,
     0.71, 0.71, 0.71, 0.71, 0.71, 0.71, 0.71, 0.71, 0.71, 0.76, 0.76, 0.76, 0.76,
     0.76, 0.76, 0.76, 0.76, 0.76, 0.76, 0.76, 0.73, 0.73, 0.73, 0.73, 0.73, 0.73,
